@@ -18,5 +18,5 @@ gtsummary::filter_hierarchical
 gtsummary::sort_hierarchical
 
 #' @export
-#' @importFrom gtsummary label_style_number
-gtsummary::label_style_number
+#' @importFrom gtsummary add_difference_row
+gtsummary::add_difference_row
